:mod:`dyff.client` --- API Client
=================================

.. module:: dyff.client
   :synopsis: APIs for interacting with the dyff platform

.. autoclass:: dyff.client.Client
   :no-show-inheritance:
   :members:
   :no-inherited-members:
   :class-doc-from: both

.. autoclass:: dyff.client.client.InferenceSessionClient()
   :no-show-inheritance:
   :members:
   :no-inherited-members:
   :class-doc-from: both

.. Note: The () on the type suppresses the default argument list, which is irrelevant
.. autoclass:: dyff.client.client.AuditsOperations()
   :no-show-inheritance:
   :members:
   :no-inherited-members:

.. autoclass:: dyff.client.client.AuditproceduresOperations()
   :no-show-inheritance:
   :members:
   :no-inherited-members:

.. autoclass:: dyff.client.client.DatasetsOperations()
   :no-show-inheritance:
   :members:
   :no-inherited-members:

.. autoclass:: dyff.client.client.EvaluationsOperations()
   :no-show-inheritance:
   :members:
   :no-inherited-members:

.. autoclass:: dyff.client.client.InferenceservicesOperations()
   :no-show-inheritance:
   :members:
   :no-inherited-members:

.. autoclass:: dyff.client.client.InferencesessionsOperations()
   :no-show-inheritance:
   :members:
   :no-inherited-members:

.. autoclass:: dyff.client.client.ModelsOperations()
   :no-show-inheritance:
   :members:
   :no-inherited-members:

.. autoclass:: dyff.client.client.ReportsOperations()
   :no-show-inheritance:
   :members:
   :no-inherited-members:
